==> wormux-0.7.9.tar.gz: wormux-0.7.9/src/weapon/bounce_ball.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2004 Lawrence Azzoug.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Bounce ball:
 * bounce since it has not collide a character
 *****************************************************************************/

#ifndef BOUNCE_BALL_H
#define BOUNCE_BALL_H

#include <SDL.h>
#include "../include/base.h"
#include "../graphic/surface.h"
#include "../gui/progress_bar.h"
#include "../object/physical_obj.h"
#include "launcher.h"

class BounceBall : public WeaponProjectile
{
  public:
    BounceBall(ExplosiveWeaponConfig& cfg,
               WeaponLauncher * p_launcher);
    void Refresh();
  protected:
    void SignalOutOfMap();
};

class BounceBallLauncher : public WeaponLauncher
{
  protected:
    bool p_Shoot ();
    WeaponProjectile * GetProjectileInstance();
  public:
    BounceBallLauncher();
};

#endif /* BOUNCE_BALL_H */

==> wormux_0.8.orig.tar.gz: wormux-0.8/src/weapon/bounce_ball.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2008 Wormux Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Bounce ball:
 * bounce since it has not collide a character
 *****************************************************************************/

#ifndef BOUNCE_BALL_H
#define BOUNCE_BALL_H

#include "weapon/weapon_launcher.h"

class BounceBallLauncher : public WeaponLauncher
{
  protected:
    bool p_Shoot ();
    WeaponProjectile * GetProjectileInstance();

    void UpdateTranslationStrings();
    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
  public:
    BounceBallLauncher();
};

#endif /* BOUNCE_BALL_H */
